Markdown - Tabler - Premium and Open Source dashboard template with responsive and high quality UI.

## Markdown

# Who’s that then?

Well, she turned me into a newt. Burn her! We want a shrubbery!! Well, I got better. Listen. Strange women lying in ponds distributing swords is no basis for a system of government. Supreme executive power derives from a mandate from the masses, not from some farcical aquatic ceremony.

Listen. Strange women lying in ponds distributing swords is no basis for a system of government. Supreme executive power derives from a mandate from the masses, not from some farcical aquatic ceremony. The swallow may fly south with the sun, and the house martin or the plover may seek warmer climes in winter, yet these are not strangers to our land.

## Well, Mercia’s a temperate zone!

You don’t frighten us, English pig-dogs! Go and boil your bottoms, sons of a silly person! I blow my nose at you, so-called Ah-thoor Keeng, you and all your silly English K-n-n-n-n-n-n-n-niggits! A newt?

1. Listen. Strange women lying in ponds distributing swords is no basis for a system of government. Supreme executive power derives from a mandate from the masses, not from some farcical aquatic ceremony.
2. I don’t want to talk to you no more, you empty-headed animal food trough water! I fart in your general direction! Your mother was a hamster and your father smelt of elderberries! Now leave before I am forced to taunt you a second time!
3. We found them.

### What do you mean?

Oh! Come and see the violence inherent in the system! Help, help, I’m being repressed! The Lady of the Lake, her arm clad in the purest shimmering samite, held aloft Excalibur from the bosom of the water, signifying by divine providence that I, Arthur, was to carry Excalibur. That is why I am your king.

- The Knights Who Say Ni demand a sacrifice!
- Be quiet!
- Bloody Peasant!

Well, I got better. Camelot! A newt? We want a shrubbery!! The Lady of the Lake, her arm clad in the purest shimmering samite, held aloft Excalibur from the bosom of the water, signifying by divine providence that I, Arthur, was to carry Excalibur. That is why I am your king.

Shut up! …Are you suggesting that coconuts migrate? I’m not a witch. Well, we did do the nose.

Well, how’d you become king, then? Shut up! Ni! Ni! Ni! Ni! Well, Mercia’s a temperate zone! I don’t want to talk to you no more, you empty-headed animal food trough water! I fart in your general direction! Your mother was a hamster and your father smelt of elderberries! Now leave before I am forced to taunt you a second time!

    $extra-colors: (
      "blue": $blue,
      "azure": $azure,
      "indigo": $indigo,
      "purple": $purple,
      "pink": $pink,
      "red": $red,
      "orange": $orange,
      "yellow": $yellow,
      "lime": $lime,
      "green": $green,
      "teal": $teal,
      "cyan": $cyan,
      "gray": $gray-600,
      "gray-dark": $gray-800,
      "dark": $dark
    ) !default;

You can’t expect to wield supreme power just ‘cause some watery tart threw a sword at you! You don’t frighten us, English pig-dogs! Go and boil your bottoms, sons of a silly person! I blow my nose at you, so-called Ah-thoor Keeng, you and all your silly English K-n-n-n-n-n-n-n-niggits!

What do you mean? Listen. Strange women lying in ponds distributing swords is no basis for a system of government. Supreme executive power derives from a mandate from the masses, not from some farcical aquatic ceremony.

Well, how’d you become king, then? You can’t expect to wield supreme power just ‘cause some watery tart threw a sword at you! The Lady of the Lake, her arm clad in the purest shimmering samite, held aloft Excalibur from the bosom of the water, signifying by divine providence that I, Arthur, was to carry Excalibur. That is why I am your king.

Well, I got better. Shut up! Will you shut up?! Well, I got better. I don’t want to talk to you no more, you empty-headed animal food trough water! I fart in your general direction! Your mother was a hamster and your father smelt of elderberries! Now leave before I am forced to taunt you a second time!

# Typographic elements

## Emphasis

This is bold text

This is bold text

This is italic text

This is italic text

Strikethrough

## Blockquotes

> Blockquotes can also be nested…

> > …by using additional greater-than signs right next to each other…

> > > …or with spaces between arrows.

Bloody Peasant! What do you mean? It’s only a model. Well, Mercia’s a temperate zone!

I am your king. Shh! Knights, I bid you welcome to your new home. Let us ride to Camelot! Ni! Ni! Ni! Ni! Who’s that then? Listen. Strange women lying in ponds distributing swords is no basis for a system of government. Supreme executive power derives from a mandate from the masses, not from some farcical aquatic ceremony.

## Lists

Unordered

- Create a list by starting a line with `+`, `-`, or `*`
- Sub-lists are made by indenting 2 spaces:
  - Marker character change forces new list start:
    - Ac tristique libero volutpat at
    - Facilisis in pretium nisl aliquet
    - Nulla volutpat aliquam velit
- Very easy!

Ordered

1. Lorem ipsum dolor sit amet
2. Consectetur adipiscing elit
3. Integer molestie lorem at massa

## Code

Inline `code`

Indented code

    // Some comments
    line 1 of code
    line 2 of code
    line 3 of code

Block code “fences”

    Sample text here...

Syntax highlighting

    var foo = function (bar) {
      return bar++;
    };

    console.log(foo(5));